@@ -128,6 +128,18 @@ MODEL_CONFIGS = [
         weights_url="https://civitai.com/api/download/models/1144",
         default_image_size=512,
     ),
+    ModelConfig(
+        short_name="ModernDisney",
+        config_path="configs/stable-diffusion-v1.yaml",
+        weights_url="https://huggingface.co/nitrosocke/mo-di-diffusion/blob/main/moDi-v1-pruned.ckpt",
+        default_image_size=512,
+    ),
+    ModelConfig(
+        short_name="ModernBuildings_SD21",
+        config_path="configs/stable-diffusion-v2-inference.yaml",
+        weights_url="https://civitai.com/api/download/models/3002",
+        default_image_size=768,
+    ),
     # ModelConfig(
     #     short_name="SD-2.0-upscale",
     #     config_path="configs/stable-diffusion-v2-upscaling.yaml",
